@@ -1,22 +1,24 @@
 stan_mcmc <- function(
-    model_type,
-    data,
-    n_mu,
-    n_tau,
-    x_alpha,
-    x_delta,
-    x_beta,
-    s_alpha,
-    s_delta,
-    s_beta,
-    s_sigma,
-    s_lambda,
-    s_mu,
-    s_tau,
-    alpha_rep_index,
-    covariance_current,
-    covariance_historical,
-    args
+  model_type,
+  data,
+  n_mu,
+  n_tau,
+  x_alpha,
+  x_delta,
+  x_beta,
+  s_alpha,
+  s_delta,
+  s_beta,
+  s_sigma,
+  s_lambda,
+  s_mu,
+  s_tau,
+  d_tau,
+  prior_tau,
+  alpha_rep_index,
+  covariance_current,
+  covariance_historical,
+  args
 ) {
   response <- data$response
   hbl_warn_identifiable(
@@ -95,6 +97,13 @@ stan_mcmc <- function(
     s_lambda = s_lambda,
     s_mu = s_mu,
     s_tau = s_tau,
+    d_tau = d_tau,
+    u_tau = if_any(prior_tau == "half_t", Inf, s_tau),
+    prior_tau = switch(
+      prior_tau,
+      half_t = 1L,
+      uniform = 2L
+    ),
     missing = missing,
     alpha_rep_index = alpha_rep_index,
     alpha_data_index = alpha_data_index,
